import { IEventTag } from '../types'
import { interceptRequests } from './request-interception'
import { getHost } from '../tracktor'

const spec: [IEventTag] = [
  {
    framework: 'dom',
    url: 'http://localhost:4444/',
    taggingMethod: 'event',
    selector:
      'html > body > div#top > main:nth-child(3) > section#embedded > article#embedded__images > div:nth-child(2) > p:nth-child(2) > img:nth-child(1)',
    handler: 'click',
    event: 'Click Picture'
  }
]
const newSpec: [IEventTag] = [
  {
    framework: 'dom',
    url: 'http://localhost:4444/',
    taggingMethod: 'event',
    selector:
      'html > body > div#top > main:nth-child(3) > section#embedded > article#embedded__images > div:nth-child(2) > p:nth-child(2) > img:nth-child(1)',
    handler: 'click',
    event: 'Click New Picture'
  }
]

// Map of all requests we want to stub out with local values
const responseMap = {
  [getHost()]: spec,
  'api.segment.io': { success: true }
}

describe('Tracktor', () => {
  beforeAll(async () => {
    interceptRequests(page, responseMap)
    await page.goto('https://localhost:4444')
    await page.waitForFunction('Tracktor.instance.isInitialized()')
  })

  it('should fire an event with the new spec when restart is called', async () => {
    const imageClickedTag = spec[0]
    const imageClickedNewTag = newSpec[0]

    page.waitForFunction(
      `Tracktor.instance.restart(${JSON.stringify(newSpec)})`
    )

    await expect(page).toClick(imageClickedTag.selector)
    const ajsTrackCall = await page
      .waitForRequest(request =>
        request.url().startsWith('https://api.segment.io/v1/t')
      )
      .then(e => e.postData())
      .then(JSON.parse)

    expect(ajsTrackCall.event).toEqual(imageClickedNewTag.event)
  })
})
