import { Page, Request } from 'puppeteer'
import url from 'url'

function respondWithJson(req: Request, content: any) {
  req.respond({
    headers: {
      'Access-Control-Allow-Origin': '*',
      'Content-Type': 'application/octet-stream'
    },
    body: JSON.stringify(content)
  })
}

/**
 * Utility for short circuiting outbound requests with data provided
 * via a responseMap
 * @param page
 * @param responseMap
 */
export async function interceptRequests(
  page: Page,
  responseMap: { [hostname: string]: any }
) {
  await page.setRequestInterception(true)
  page.on('request', request => {
    const { hostname } = url.parse(request.url().toString())
    const mockedResponse = responseMap[hostname!]

    if (mockedResponse) {
      respondWithJson(request, mockedResponse)
      return
    }

    request.continue()
  })
}
